<h1 align="center" style="border-bottom: none">
    <a href="https://kortecx.com/">
        <img alt="Kortecx logo" src="assets/kortecx_readme.png" width="400" />
    </a>
</h1>
<h2 align="center" style="border-bottom: none">Executable intelligence Platform </h2>

Kortecx is an open-source zero-hassle library to generalize the training and finetuning LLMs at scale, synthesize and engineer data, and build Agentic AI solutions.

</div>


<div align="center">

[![Python SDK](https://img.shields.io/pypi/v/kortecx)](https://pypi.org/project/kortecx/)
[![PyPI Downloads](https://img.shields.io/pypi/dm/kortecx)](https://pepy.tech/projects/kortecx)
[![License](https://img.shields.io/github/license/kortecx/kortecx)](https://raw.githubusercontent.com/Kortecx/kortecx/refs/heads/main/LICENSE.txt)
<a href="https://twitter.com/intent/follow?screen_name=kortecx" target="_blank">
<img src="https://img.shields.io/twitter/follow/kortecx?logo=X&color=%20%23f5f5f5"
      alt="follow on X(Twitter)"></a>
<a href="https://www.linkedin.com/company/kortecx/" target="_blank">
<img src="https://custom-icon-badges.demolab.com/badge/LinkedIn-0A66C2?logo=linkedin-white&logoColor=fff"
      alt="follow on LinkedIn"></a>

</div>

<div align="center">
   <div>
      <a href="https://kortecx.com/"><strong>Website</strong></a> ·
      <a href="https://kortecx.com/docs"><strong>Docs</strong></a> ·
      <a href="https://github.com/Kortecx/kortecx/issues/new/choose"><strong>Feature Request</strong></a> ·
      <a href="https://www.youtube.com/@executableintelligence"><strong>YouTube</strong></a>
   </div>
</div>
